tlslite.utils.aes.AES

Package tlslite :: Package utils :: Module aes :: Class AES |
[hide private]
[frames] | no frames]

# Class AES

source code

Known Subclasses:
  - openssl_aes.OpenSSL_AES
  - , pycrypto_aes.PyCrypto_AES
  - , python_aes.Python_AES

Instance Methods | [hide private]
__init__(self, key, mode, IV, implementation) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code